@@ -8,7 +8,7 @@ use base qw(Catalyst::Component::ACCEPT_CONTEXT Catalyst::Model);
 my $foo = 'bar';
 sub new {
     my $self = shift;
-    $self = $self->NEXT::new(@_);
+    $self = $self->next::method(@_);
     $foo = $self->context->config->{foo};
     return $self;
 }
